summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/workspace/tqworkspace.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitd296f1d337dabfeae5191955fdadb874965dbbe9 (patch)
tree1a4b3b4cca01f2ea77eee2497297219d60e9bbd4 /tqtinterface/qt4/src/workspace/tqworkspace.cpp
parenteaa7ee2e0bbca40ba3173c4304f81957e8964291 (diff)
downloadexperimental-d296f1d337dabfeae5191955fdadb874965dbbe9.tar.gz
experimental-d296f1d337dabfeae5191955fdadb874965dbbe9.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'tqtinterface/qt4/src/workspace/tqworkspace.cpp')
-rw-r--r--tqtinterface/qt4/src/workspace/tqworkspace.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/tqtinterface/qt4/src/workspace/tqworkspace.cpp b/tqtinterface/qt4/src/workspace/tqworkspace.cpp
index a4e2687..531a78e 100644
--- a/tqtinterface/qt4/src/workspace/tqworkspace.cpp
+++ b/tqtinterface/qt4/src/workspace/tqworkspace.cpp
@@ -91,11 +91,11 @@
document windows, each of which is a widget.
The workspace itself is an ordinary TQt widget. It has a standard
- constructor that takes a tqparent widget and an object name. The
- tqparent window is usually a TQMainWindow, but it need not be.
+ constructor that takes a parent widget and an object name. The
+ parent window is usually a TQMainWindow, but it need not be.
Document windows (i.e. MDI windows) are also ordinary TQt widgets
- which have the workspace as their tqparent widget. When you call
+ which have the workspace as their parent widget. When you call
show(), hide(), showMaximized(), setCaption(), etc. on a document
window, it is shown, hidden, etc. with a frame, caption, icon and
icon text, just as you'd expect. You can provide widget flags
@@ -146,7 +146,7 @@ class TQWorkspaceChild : public TQFrame
public:
TQWorkspaceChild( TQWidget* window,
- TQWorkspace* tqparent=0, const char* name=0 );
+ TQWorkspace* parent=0, const char* name=0 );
~TQWorkspaceChild();
void setActive( bool );
@@ -249,34 +249,34 @@ public:
TQPtrList<TQDockWindow> dockwindows, newdocks;
};
-static bool isChildOf( TQWidget * child, TQWidget * tqparent )
+static bool isChildOf( TQWidget * child, TQWidget * parent )
{
- if ( !tqparent || !child )
+ if ( !parent || !child )
return FALSE;
TQWidget * w = child;
- while( w && w != tqparent )
+ while( w && w != parent )
w = w->parentWidget();
return w != 0;
}
/*!
- Constructs a workspace with a \a tqparent and a \a name.
+ Constructs a workspace with a \a parent and a \a name.
*/
-TQWorkspace::TQWorkspace( TQWidget *tqparent, const char *name )
- : TQWidget( tqparent, name )
+TQWorkspace::TQWorkspace( TQWidget *parent, const char *name )
+ : TQWidget( parent, name )
{
init();
}
#ifdef TQT_WORKSPACE_WINDOWMODE
/*!
- Constructs a workspace with a \a tqparent and a \a name. This
+ Constructs a workspace with a \a parent and a \a name. This
constructor will also set the WindowMode to \a mode.
\sa windowMode()
*/
-TQWorkspace::TQWorkspace( TQWorkspace::WindowMode mode, TQWidget *tqparent, const char *name )
- : TQWidget( tqparent, name )
+TQWorkspace::TQWorkspace( TQWorkspace::WindowMode mode, TQWidget *parent, const char *name )
+ : TQWidget( parent, name )
{
init();
d->wmode = mode;
@@ -1045,7 +1045,7 @@ void TQWorkspace::showEvent( TQShowEvent *e )
setGeometry(0, 0, w->width(), w->height());
#if 0
/* Hide really isn't acceptable because I need to make the rest of TQt
- think it is visible, so instead I set it to an empty tqmask. I'm not
+ think it is visible, so instead I set it to an empty mask. I'm not
sure what problems this is going to create, hopefully everything will
be happy (or not even notice since this is mostly intended for TQt/Mac) */
// w->setMask(TQRegion());
@@ -1311,7 +1311,7 @@ TQWidgetList TQWorkspace::windowList( WindowOrder order ) const
/*!\reimp*/
bool TQWorkspace::eventFilter( TQObject *o, TQEvent * e)
{
- if(d->wmode == TopLevel && d->mainwindow && TQT_BASE_OBJECT(TQT_TQOBJECT(o)->tqparent()) == TQT_BASE_OBJECT(d->mainwindow)) {
+ if(d->wmode == TopLevel && d->mainwindow && TQT_BASE_OBJECT(TQT_TQOBJECT(o)->parent()) == TQT_BASE_OBJECT(d->mainwindow)) {
if((e->type() == TQEvent::ChildInserted || e->type() == TQEvent::Reparent) &&
::tqqt_cast<TQDockArea*>(o) && !((TQWidget*)o)->isVisible()) {
TQChildEvent *ce = (TQChildEvent*)e;
@@ -1341,7 +1341,7 @@ bool TQWorkspace::eventFilter( TQObject *o, TQEvent * e)
switch ( e->type() ) {
case TQEvent::MouseButtonPress:
{
- TQMenuBar* b = (TQMenuBar*)o->tqparent();
+ TQMenuBar* b = (TQMenuBar*)o->parent();
if ( !t )
t = new TQTime;
if ( tc != this || t->elapsed() > TQApplication::doubleClickInterval() ) {
@@ -1473,7 +1473,7 @@ void TQWorkspace::showMaximizeControls()
TQ_ASSERT(d->maxWindow);
TQMenuBar* b = 0;
// Do a breadth-first search first on every tqparent,
TQWidget* w = parentWidget();
TQObjectList * l = 0;
while ( !l && w ) {
@@ -2026,10 +2026,10 @@ void TQWorkspace::tile()
blockSignals(FALSE);
}
-TQWorkspaceChild::TQWorkspaceChild( TQWidget* window, TQWorkspace *tqparent,
+TQWorkspaceChild::TQWorkspaceChild( TQWidget* window, TQWorkspace *parent,
const char *name )
- : TQFrame( tqparent, name,
- (WFlags)((tqparent->windowMode() == TQWorkspace::TopLevel ? (TQt::WStyle_MinMax | TQt::WStyle_SysMenu | TQt::WType_TopLevel) :
+ : TQFrame( parent, name,
+ (WFlags)((parent->windowMode() == TQWorkspace::TopLevel ? (TQt::WStyle_MinMax | TQt::WStyle_SysMenu | TQt::WType_TopLevel) :
TQt::WStyle_NoBorder ) | WStyle_Customize | TQt::WDestructiveClose | TQt::WNoMousePropagation | TQt::WSubWindow) )
{
statusbar = 0;
@@ -2055,7 +2055,7 @@ TQWorkspaceChild::TQWorkspaceChild( TQWidget* window, TQWorkspace *tqparent,
}
}
- if ( window && window->testWFlags( TQt::WStyle_Title ) && tqparent->windowMode() != TQWorkspace::TopLevel ) {
+ if ( window && window->testWFlags( TQt::WStyle_Title ) && parent->windowMode() != TQWorkspace::TopLevel ) {
titlebar = new TQTitleBar( window, this, "qt_ws_titlebar" );
connect( titlebar, TQT_SIGNAL( doActivate() ),
this, TQT_SLOT( activate() ) );
@@ -2135,14 +2135,14 @@ TQWorkspaceChild::TQWorkspaceChild( TQWidget* window, TQWorkspace *tqparent,
childWidget->installEventFilter( this );
widgetResizeHandler = new TQWidgetResizeHandler( this, window );
- widgetResizeHandler->setSizeProtection( !tqparent->scrollBarsEnabled() );
+ widgetResizeHandler->setSizeProtection( !parent->scrollBarsEnabled() );
connect( widgetResizeHandler, TQT_SIGNAL( activate() ),
this, TQT_SLOT( activate() ) );
if ( !tqstyle().tqstyleHint( TQStyle::SH_TitleBar_NoBorder, titlebar ) )
widgetResizeHandler->setExtraHeight( th + contentsRect().y() - 2*frameWidth() );
else
widgetResizeHandler->setExtraHeight( th + contentsRect().y() - frameWidth() );
- if(tqparent->windowMode() == TQWorkspace::TopLevel && isTopLevel()) {
+ if(parent->windowMode() == TQWorkspace::TopLevel && isTopLevel()) {
move(0, 0);
widgetResizeHandler->setActive( FALSE );
}
@@ -2775,7 +2775,7 @@ void TQWorkspaceChild::internalRaise()
return;
}
- TQPtrListIterator<TQWorkspaceChild> it( ((TQWorkspace*)tqparent())->d->windows );
+ TQPtrListIterator<TQWorkspaceChild> it( ((TQWorkspace*)parent())->d->windows );
while ( it.current () ) {
TQWorkspaceChild* c = it.current();
++it;
@@ -1473,7 +1473,7 @@ void TQWorkspace::showMaximizeControls()
TQ_ASSERT(d->maxWindow);
TQMenuBar* b = 0;
- // Do a breadth-first search first on every tqparent,
+ // Do a breadth-first search first on every parent,
TQWidget* w = parentWidget();
TQObjectList * l = 0;